diff --git a/Janus/JanusMessages.cs b/Janus/JanusMessages.cs
index b42086e..694a3da 100644
--- a/Janus/JanusMessages.cs
+++ b/Janus/JanusMessages.cs
@@ -355,13 +355,13 @@ namespace WebRtcVoice
public AudioBridgeCreateRoomReq(int pRoomId) : this(pRoomId, false, null)
{
}
- public AudioBridgeCreateRoomReq(int pRoomId, bool pSpacial, string pDesc) : base(new OSDMap() {
+ public AudioBridgeCreateRoomReq(int pRoomId, bool pSpatial, string pDesc) : base(new OSDMap() {
{ "room", pRoomId },
{ "request", "create" },
{ "is_private", false },
{ "permanent", false },
{ "sampling_rate", 48000 },
- { "spatial_audio", pSpacial },
+ { "spatial_audio", pSpatial },
{ "denoise", false },
{ "record", false }
})
diff --git a/Janus/WebRtcJanusService.cs b/Janus/WebRtcJanusService.cs
index 0b98c19..b49d233 100644
--- a/Janus/WebRtcJanusService.cs
+++ b/Janus/WebRtcJanusService.cs
@@ -195,7 +195,7 @@ namespace WebRtcVoice
string channel_id = pRequest.ContainsKey("channel_id") ? pRequest["channel_id"].AsString() : String.Empty;
string channel_credentials = pRequest.ContainsKey("credentials") ? pRequest["credentials"].AsString() : String.Empty;
string channel_type = pRequest["channel_type"].AsString();
- bool isSpacial = channel_type == "local";
+ bool isSpatial = channel_type == "local";
string voice_server_type = pRequest["voice_server_type"].AsString();
_log.DebugFormat("{0} ProvisionVoiceAccountRequest: parcel_id={1} channel_id={2} channel_type={3} voice_server_type={4}", LogHeader, parcel_local_id, channel_id, channel_type, voice_server_type);
@@ -210,7 +210,7 @@ namespace WebRtcVoice
// The client is sending an offer. Find the right room and join it.
// _log.DebugFormat("{0} ProvisionVoiceAccountRequest: jsep type={1} sdp={2}", LogHeader, jsepType, jsepSdp);
viewerSession.Room = await viewerSession.AudioBridge.SelectRoom(pScene.RegionInfo.RegionID.ToString(),
- channel_type, isSpacial, parcel_local_id, channel_id);
+ channel_type, isSpatial, parcel_local_id, channel_id);
if (viewerSession.Room is null)
{
errorMsg = "room selection failed";
@@ -387,7 +387,7 @@ namespace WebRtcVoice
{
MainConsole.Instance.Output(
" {0,10} {1,15} {2,5} {3,10} {4,7} {5,7}",
- "Room", "Description", "Num", "SampleRate", "Spacial", "Recording");
+ "Room", "Description", "Num", "SampleRate", "Spatial", "Recording");
foreach (OSDMap room in list as OSDArray)
{
MainConsole.Instance.Output(
diff --git a/os-webrtc-janus.ini b/os-webrtc-janus.ini
index dc275cc..b132604 100644
--- a/os-webrtc-janus.ini
+++ b/os-webrtc-janus.ini
@@ -3,9 +3,9 @@
; Module to load for WebRtcVoice
BaseService=WebRtcVoice.dll:WebRtcVoiceService
; Module to use for spacial WebRtcVoice
- SpacialVoiceService=WebRtcJanusService.dll:WebRtcJanusService
+ SpatialVoiceService=WebRtcJanusService.dll:WebRtcJanusService
; Module to use for non-spacial WebRtcVoice
- NonSpacialVoiceService=WebRtcJanusService.dll:WebRtcJanusService
+ NonSpatialVoiceService=WebRtcJanusService.dll:WebRtcJanusService
; URL for the grid service that is providing the WebRtcVoiceService
WebRtcVoiceServerURI = ${Const|PrivURL}:${Const|PrivatePort}
diff --git a/Janus/JanusAudioBridge.cs b/Janus/JanusAudioBridge.cs
index e1e068b..0cefa1d 100644
--- a/Janus/JanusAudioBridge.cs
+++ b/Janus/JanusAudioBridge.cs
@@ -61,15 +61,15 @@ namespace WebRtcVoice
/// is only being used for our voice service.
///
/// integer room ID to create
/// boolean on whether room will be spacial or non-spacial
/// added as "description" to the created room
///
- public async Task CreateRoom(int pRoomId, bool pSpacial, string pRoomDesc)
+ public async Task CreateRoom(int pRoomId, bool pSpatial, string pRoomDesc)
{
JanusRoom ret = null;
try
{
- JanusMessageResp resp = await SendPluginMsg(new AudioBridgeCreateRoomReq(pRoomId, pSpacial, pRoomDesc));
+ JanusMessageResp resp = await SendPluginMsg(new AudioBridgeCreateRoomReq(pRoomId, pSpatial, pRoomDesc));
AudioBridgeResp abResp = new AudioBridgeResp(resp);
m_log.DebugFormat("{0} CreateRoom. ReturnCode: {1}", LogHeader, abResp.AudioBridgeReturnCode);
@@ -117,7 +117,7 @@ namespace WebRtcVoice
return ret;
}
// Constant used to denote that this is a spacial audio room for the region (as opposed to parcels)
public const int REGION_ROOM_ID = -999;
private Dictionary _rooms = new Dictionary();
@@ -152,7 +152,7 @@ namespace WebRtcVoice
int roomNumber = Math.Abs(hashed.GetHashCode());
return roomNumber;
}
- public async Task SelectRoom(string pRegionId, string pChannelType, bool pSpacial, int pParcelLocalID, string pChannelID)
+ public async Task SelectRoom(string pRegionId, string pChannelType, bool pSpatial, int pParcelLocalID, string pChannelID)
{
int roomNumber = CalcRoomNumber(pRegionId, pChannelType, pParcelLocalID, pChannelID);
@@ -169,7 +169,7 @@ namespace WebRtcVoice
}
// The room doesn't exist. Create it.
- JanusRoom ret = await CreateRoom(roomNumber, pSpacial, roomNumber.ToString());
+ JanusRoom ret = await CreateRoom(roomNumber, pSpatial, roomNumber.ToString());
JanusRoom existingRoom = null;
if (ret is not null)
@@ -208,4 +208,4 @@ namespace WebRtcVoice
return ret;
}
}
-}
\ No newline at end of file
+}
@@ -61,15 +61,15 @@ namespace WebRtcVoice
///
/// integer room ID to create
- /// boolean on whether room will be spacial or non-spacial
+ /// boolean on whether room will be spatial or non-spatial
/// added as "description" to the created room
///
@@ -117,7 +117,7 @@ namespace WebRtcVoice
return ret;
}
- // Constant used to denote that this is a spacial audio room for the region (as opposed to parcels)
+ // Constant used to denote that this is a spatial audio room for the region (as opposed to parcels)
public const int REGION_ROOM_ID = -999;
private Dictionary _rooms = new Dictionary();
diff --git a/WebRtcVoiceServiceModule/WebRtcVoiceServiceModule.cs b/WebRtcVoiceServiceModule/WebRtcVoiceServiceModule.cs
index d1f6ac9..6c5ad81 100644
--- a/WebRtcVoiceServiceModule/WebRtcVoiceServiceModule.cs
+++ b/WebRtcVoiceServiceModule/WebRtcVoiceServiceModule.cs
@@ -38,9 +38,9 @@ namespace WebRtcVoice
/// Interface for the WebRtcVoiceService.
/// An instance of this is registered as the IWebRtcVoiceService for this region.
/// The function here is to direct the capability requests to the appropriate voice service.
/// For the moment, there are separate voice services for spacial and non-spacial voice
/// with the idea that a region could have a pre-region spacial voice service while
/// the grid could have a non-spacial voice service for group chat, etc.
/// Fancier configurations are possible.
///
[Extension(Path = "/OpenSim/RegionModules", NodeName = "RegionModule", Id = "WebRtcVoiceServiceModule")]
@@ -52,13 +52,13 @@ namespace WebRtcVoice
private static bool m_Enabled = false;
private IConfigSource m_Config;
- private IWebRtcVoiceService m_spacialVoiceService;
- private IWebRtcVoiceService m_nonSpacialVoiceService;
+ private IWebRtcVoiceService m_spatialVoiceService;
+ private IWebRtcVoiceService m_nonSpatialVoiceService;
// =====================================================================
// ISharedRegionModule.Initialize
// Get configuration and load the modules that will handle spacial and non-spacial voice.
public void Initialise(IConfigSource pConfig)
{
m_log.DebugFormat("{0} WebRtcVoiceServiceModule constructor", LogHeader);
@@ -71,35 +71,35 @@ namespace WebRtcVoice
if (m_Enabled)
{
// Get the DLLs for the two voice services
- string spacialDllName = moduleConfig.GetString("SpacialVoiceService", String.Empty);
- string nonSpacialDllName = moduleConfig.GetString("NonSpacialVoiceService", String.Empty);
- if (String.IsNullOrEmpty(spacialDllName) && String.IsNullOrEmpty(nonSpacialDllName))
+ string spatialDllName = moduleConfig.GetString("SpatialVoiceService", String.Empty);
+ string nonSpatialDllName = moduleConfig.GetString("NonSpatialVoiceService", String.Empty);
+ if (String.IsNullOrEmpty(spatialDllName) && String.IsNullOrEmpty(nonSpatialDllName))
{
- m_log.ErrorFormat("{0} No SpacialVoiceService or NonSpacialVoiceService specified in configuration", LogHeader);
+ m_log.ErrorFormat("{0} No SpatialVoiceService or NonSpatialVoiceService specified in configuration", LogHeader);
m_Enabled = false;
}
- // Default non-spacial to spacial if not specified
- if (String.IsNullOrEmpty(nonSpacialDllName))
+ // Default non-spatial to spatial if not specified
+ if (String.IsNullOrEmpty(nonSpatialDllName))
{
- m_log.DebugFormat("{0} nonSpacialDllName not specified. Defaulting to spacialDllName", LogHeader);
- nonSpacialDllName = spacialDllName;
+ m_log.DebugFormat("{0} nonSpatialDllName not specified. Defaulting to spatialDllName", LogHeader);
+ nonSpatialDllName = spatialDllName;
}
// Load the two voice services
- m_log.DebugFormat("{0} Loading SpacialVoiceService from {1}", LogHeader, spacialDllName);
- m_spacialVoiceService = ServerUtils.LoadPlugin(spacialDllName, new object[] { m_Config });
- if (m_spacialVoiceService is null)
+ m_log.DebugFormat("{0} Loading SpatialVoiceService from {1}", LogHeader, spatialDllName);
+ m_spatialVoiceService = ServerUtils.LoadPlugin(spatialDllName, new object[] { m_Config });
+ if (m_spatialVoiceService is null)
{
- m_log.ErrorFormat("{0} Could not load SpacialVoiceService from {1}", LogHeader, spacialDllName);
+ m_log.ErrorFormat("{0} Could not load SpatialVoiceService from {1}", LogHeader, spatialDllName);
m_Enabled = false;
}
- m_log.DebugFormat("{0} Loading NonSpacialVoiceService from {1}", LogHeader, nonSpacialDllName);
- m_nonSpacialVoiceService = ServerUtils.LoadPlugin(nonSpacialDllName, new object[] { m_Config });
- if (m_nonSpacialVoiceService is null)
+ m_log.DebugFormat("{0} Loading NonSpatialVoiceService from {1}", LogHeader, nonSpatialDllName);
+ m_nonSpatialVoiceService = ServerUtils.LoadPlugin(nonSpatialDllName, new object[] { m_Config });
+ if (m_nonSpatialVoiceService is null)
{
- m_log.ErrorFormat("{0} Could not load NonSpacialVoiceService from {1}", LogHeader, nonSpacialDllName);
+ m_log.ErrorFormat("{0} Could not load NonSpatialVoiceService from {1}", LogHeader, nonSpatialDllName);
m_Enabled = false;
}
@@ -213,13 +213,13 @@ namespace WebRtcVoice
if (channelType == "local")
{
// TODO: check if this userId is making a new session (case that user is reconnecting)
- vSession = m_spacialVoiceService.CreateViewerSession(pRequest, pUserID, pScene);
+ vSession = m_spatialVoiceService.CreateViewerSession(pRequest, pUserID, pScene);
VoiceViewerSession.AddViewerSession(vSession);
}
else
{
// TODO: check if this userId is making a new session (case that user is reconnecting)
- vSession = m_nonSpacialVoiceService.CreateViewerSession(pRequest, pUserID, pScene);
+ vSession = m_nonSpatialVoiceService.CreateViewerSession(pRequest, pUserID, pScene);
VoiceViewerSession.AddViewerSession(vSession);
}
}
@@ -38,9 +38,9 @@ namespace WebRtcVoice
/// An instance of this is registered as the IWebRtcVoiceService for this region.
/// The function here is to direct the capability requests to the appropriate voice service.
- /// For the moment, there are separate voice services for spacial and non-spacial voice
- /// with the idea that a region could have a pre-region spacial voice service while
- /// the grid could have a non-spacial voice service for group chat, etc.
+ /// For the moment, there are separate voice services for spatial and non-spatial voice
+ /// with the idea that a region could have a pre-region spatial voice service while
+ /// the grid could have a non-spatial voice service for group chat, etc.
/// Fancier configurations are possible.
///
@@ -52,13 +52,13 @@ namespace WebRtcVoice
// =====================================================================
// ISharedRegionModule.Initialize
- // Get configuration and load the modules that will handle spacial and non-spacial voice.
+ // Get configuration and load the modules that will handle spatial and non-spatial voice.
public void Initialise(IConfigSource pConfig)
{